@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.30 2004/02/20 11:49:42 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.30.6.3 2004/04/18 10:29:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,6 +30,28 @@
 
 static void ephy_embed_base_init (gpointer g_class);
 
+GType
+ephy_embed_chrome_get_type (void)
+{
+	static GType etype = 0;
+
+	if (etype == 0)
+	{
+		static const GFlagsValue values[] =
+		{
+		{ EPHY_EMBED_CHROME_MENUBAR, "EPHY_EMBED_CHROME_MENUBAR", "menubar" },
+		{ EPHY_EMBED_CHROME_TOOLBAR, "EPHY_EMBED_CHROME_TOOLBAR", "toolbar" },
+		{ EPHY_EMBED_CHROME_STATUSBAR, "EPHY_EMBED_CHROME_STATUSBAR", "statusbar" },
+		{ EPHY_EMBED_CHROME_BOOKMARKSBAR, "EPHY_EMBED_CHROME_BOOKMARKSBAR", "bookmarksbar" },
+		{ 0, NULL, NULL }
+		};
+
+		etype = g_flags_register_static ("EphyEmbedChrome", values);
+	}
+
+	return etype;
+}
+
 GType
 ephy_embed_get_type (void)
 {
