@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.31 2004/03/03 21:53:19 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.31.4.2 2004/04/18 10:12:10 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -485,6 +485,11 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	PRInt32 flags = nsIWebBrowserPersist::PERSIST_FLAGS_REPLACE_EXISTING_FILES;
+
+	if (!isHTML)
+	{
+		flags |= nsIWebBrowserPersist::PERSIST_FLAGS_NO_CONVERSION;
+	}
 	if (ephy_flags & EMBED_PERSIST_COPY_PAGE)
 	{
 		flags |= nsIWebBrowserPersist::PERSIST_FLAGS_FROM_CACHE;
@@ -503,10 +508,12 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 		PRInt32 encodingFlags = 0;
 		nsCOMPtr<nsILocalFile> filesFolder;
 
-    		if (contentType && strcmp (contentType, "text/plain") == 0)
+    		if (!contentType || strcmp (contentType, "text/plain") != 0)
 		{
-			/* Create a local directory in the same dir as our file.  It
-			   will hold our associated files. */
+			/**
+			 * Construct a directory path to hold the associated files; mozilla
+			 * will create the directory as needed.
+			 */
 
 			filesFolder = do_CreateInstance("@mozilla.org/file/local;1");
 			nsAutoString unicodePath;
@@ -522,15 +529,8 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 				nameMinusExt.Left(nameMinusExt, index);
 			}
 
-			nameMinusExt += NS_LITERAL_STRING(" Files");
+			nameMinusExt += NS_LITERAL_STRING (" Files");
 			filesFolder->SetLeafName(nameMinusExt);
-			PRBool exists = PR_FALSE;
-			filesFolder->Exists(&exists);
-			if (!exists)
-			{
-				rv = filesFolder->Create(nsILocalFile::DIRECTORY_TYPE, 0755);
-				if (NS_FAILED(rv)) return rv;
-			}
 		}
 		else
 		{
