@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.31 2004/02/21 19:56:05 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.31.4.1 2004/04/05 17:52:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1285,7 +1285,15 @@ ephy_dialog_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static void
+GtkWidget *
+ephy_dialog_get_parent (EphyDialog *dialog)
+{
+	g_return_val_if_fail (EPHY_IS_DIALOG (dialog), NULL);
+
+	return dialog->priv->parent;
+}
+
+void
 ephy_dialog_set_parent (EphyDialog *dialog,
 			GtkWidget *parent)
 {
