@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.14 2004/02/21 19:59:01 chpe Exp $
+ *  $Id: ephy-gui.c,v 1.14.4.1 2004/04/09 21:40:32 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -78,18 +78,23 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 gboolean
 ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
 {
-	char *question;
+	char *question, *converted;
 	GtkWidget *dialog;
 	gboolean res;
 
+	if (filename == NULL) return FALSE;
+
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS))
 	{
 		return TRUE;
 	}
 
+	converted = g_filename_to_utf8 (filename, -1, NULL, NULL, NULL);
+	if (converted == NULL) return FALSE;
+
 	question = g_strdup_printf (_("File %s will be overwritten.\n"
 				    "If you choose yes, the contents will be lost.\n\n"
-				    "Do you want to continue?"), filename);
+				    "Do you want to continue?"), converted);
 	dialog = gtk_message_dialog_new (parent ? GTK_WINDOW(parent) : NULL,
 			                 GTK_DIALOG_MODAL,
 				         GTK_MESSAGE_QUESTION,
@@ -98,6 +103,7 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
 	res = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES);
 	gtk_widget_destroy (dialog);
 	g_free (question);
+	g_free (converted);
 
 	return res;
 }
