@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.76 2004/02/27 14:50:00 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.76.4.2 2004/04/05 17:52:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1256,16 +1256,14 @@ void
 prefs_homepage_current_button_clicked_cb (GtkWidget *button,
 					  EphyDialog *dialog)
 {
-	EphySession *session;
-	EphyWindow *window;
+	GtkWidget *parent;
 	EphyEmbed *embed;
 	char *location;
 
-	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
-	window = ephy_session_get_active_window (session);
-	g_return_if_fail (window != NULL);
+	parent = ephy_dialog_get_parent (dialog);
+	g_return_if_fail (parent != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_window_get_active_embed (EPHY_WINDOW (parent));
 	g_return_if_fail (embed != NULL);
 
 	location = ephy_embed_get_location (embed, TRUE);
@@ -1282,7 +1280,7 @@ prefs_homepage_blank_button_clicked_cb (GtkWidget *button,
 static void
 download_path_response_cb (GtkDialog *fc, gint response, EphyDialog *dialog)
 {
-	if (response == EPHY_RESPONSE_OPEN)
+	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		char *dir;
 
