@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.115 2004/03/04 19:32:29 chpe Exp $
+ *  $Id: window-commands.c,v 1.115.4.4 2004/04/05 17:52:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -76,6 +76,7 @@ window_cmd_file_print_setup (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_print_setup_dialog (ephy_shell));
+	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -364,7 +365,7 @@ window_cmd_file_bookmark_page (GtkAction *action,
 static void
 open_response_cb (GtkDialog *dialog, int response, EphyWindow *window)
 {
-	if (response == EPHY_RESPONSE_OPEN)
+	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		char *uri, *converted;
 
@@ -586,36 +587,6 @@ window_cmd_edit_find_prev (GtkAction *action,
 	ephy_embed_find_next (embed, TRUE);
 }
 
-void
-window_cmd_view_bookmarks_bar (GtkAction *action,
-			       EphyWindow *window)
-{
-	gboolean active;
-
-	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_WINDOWS_SHOW_BOOKMARKS_BAR, active);
-}
-
-void
-window_cmd_view_toolbar (GtkAction *action,
-			 EphyWindow *window)
-{
-	gboolean active;
-
-	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_WINDOWS_SHOW_TOOLBARS, active);
-}
-
-void
-window_cmd_view_statusbar (GtkAction *action,
-			   EphyWindow *window)
-{
-	gboolean active;
-
-	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	eel_gconf_set_boolean (CONF_WINDOWS_SHOW_STATUSBAR, active);
-}
-
 void
 window_cmd_view_fullscreen (GtkAction *action,
 			    EphyWindow *window)
@@ -815,6 +786,7 @@ window_cmd_edit_personal_data (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_pdm_dialog (ephy_shell));
+	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -826,6 +798,7 @@ window_cmd_edit_prefs (GtkAction *action,
 	EphyDialog *dialog;
 
 	dialog = EPHY_DIALOG (ephy_shell_get_prefs_dialog (ephy_shell));
+	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
 
 	ephy_dialog_show (dialog);
 }
@@ -987,6 +960,8 @@ window_cmd_help_about (GtkAction *action,
 		       strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 		       logo);
 
+	gtk_window_set_icon (GTK_WINDOW (about), logo);
+
 	if (logo != NULL)
 	{
 		g_object_unref (logo);
